@@ -35,13 +35,13 @@ void about_cb(GtkWidget *widget, void *data)
         };  
 
         about = gnome_about_new ( 
-        	"TCD - The Gnome CD Player", 
+        	N_("TCD - The Gnome CD Player"), 
         	"2.2 (CVS)",
                 "(C) 1997-98 Tim P. Gerla",
                 (const gchar**)authors,
-                "Gnome CD player application with CDDB support."
-                " Please see the \'Thanks\' file included with the"
-                " distribution for more credits.",
+                N_("Gnome CD player application with CDDB support."
+                   " Please see the \'Thanks\' file included with the"
+                   " distribution for more credits."),
                 NULL);
         gtk_widget_show(about);
 
