@@ -107,7 +107,7 @@ void select_row_cb( GtkCList *clist,
 	
 void edit_window( void )
 {
-	char *titles[] = {"Trk","Time","Title"};
+	char *titles[] = {N_("Trk"),N_("Time"),N_("Title")};
 	
 	GtkWidget *disc_entry, *disc_ext;
 	GtkWidget *label, *disc_frame, *button_box;
@@ -122,7 +122,7 @@ void edit_window( void )
 
 	trwin = gtk_window_new(GTK_WINDOW_DIALOG);
 	gtk_container_border_width(GTK_CONTAINER(trwin), 5);
-	gtk_window_set_title(GTK_WINDOW(trwin), "Track Editor");
+	gtk_window_set_title(GTK_WINDOW(trwin), N_("Track Editor"));
 	gtk_window_set_wmclass(GTK_WINDOW(trwin), "track_editor","gtcd");
 
 	gtk_signal_connect(GTK_OBJECT(trwin), "delete_event",
@@ -137,9 +137,9 @@ void edit_window( void )
 	
 	/* Disc area */
 	disc_table  = gtk_table_new(2, 2, FALSE);
-	disc_frame = gtk_frame_new("Disc Information");
-	label 	   = gtk_label_new("Artist / Title");
-	disc_ext   = gtk_button_new_with_label("Ext Data");
+	disc_frame = gtk_frame_new(N_("Disc Information"));
+	label 	   = gtk_label_new(N_("Artist / Title"));
+	disc_ext   = gtk_button_new_with_label(N_("Ext Data"));
 	gtk_widget_set_sensitive(disc_ext, FALSE);
 	disc_entry = gtk_entry_new();
 	gtk_entry_set_text(GTK_ENTRY(disc_entry), cd.dtitle);
@@ -160,7 +160,7 @@ void edit_window( void )
 	entry_box   = gtk_hbox_new(FALSE, 2);
 	track_entry = gtk_entry_new();
 	gtk_entry_set_text(GTK_ENTRY(track_entry), cd.trk[1].name);
-	track_ext   = gtk_button_new_with_label("Ext Data");
+	track_ext   = gtk_button_new_with_label(N_("Ext Data"));
 	gtk_widget_set_sensitive(track_ext, FALSE);
 	track_list  = gtk_clist_new_with_titles(3, titles);
 	gtk_clist_set_border(GTK_CLIST(track_list), GTK_SHADOW_NONE);
@@ -173,7 +173,7 @@ void edit_window( void )
 	gtk_clist_column_titles_passive(GTK_CLIST(track_list));
 	gtk_widget_set_usize(track_list, 150, 225 );
 	fill_list(track_list);
-	track_frame = gtk_frame_new("Track Information");
+	track_frame = gtk_frame_new(N_("Track Information"));
 	
 	gtk_box_pack_start_defaults(GTK_BOX(entry_box), track_entry);
 	gtk_box_pack_start_defaults(GTK_BOX(entry_box), track_ext);
@@ -184,16 +184,16 @@ void edit_window( void )
 	/* END Track area */
 
 	button_box = gtk_hbox_new(FALSE,2);
-	button = gtk_button_new_with_label("CDDB Get");
+	button = gtk_button_new_with_label(N_("CDDB Get"));
 	gtk_widget_set_sensitive(button, FALSE);
 	gtk_box_pack_start_defaults(GTK_BOX(button_box), button);
-	button = gtk_button_new_with_label("Submit");
+	button = gtk_button_new_with_label(N_("Submit"));
 	gtk_widget_set_sensitive(button, FALSE);
 	gtk_box_pack_start_defaults(GTK_BOX(button_box), button);
-	button = gtk_button_new_with_label("Clear");
+	button = gtk_button_new_with_label(N_("Clear"));
 	gtk_widget_set_sensitive(button, FALSE);
 	gtk_box_pack_start_defaults(GTK_BOX(button_box), button);
-	button = gtk_button_new_with_label("Playlist");
+	button = gtk_button_new_with_label(N_("Playlist"));
 	gtk_widget_set_sensitive(button, FALSE);
 	gtk_box_pack_start_defaults(GTK_BOX(button_box), button);
 	gtk_box_pack_start_defaults(GTK_BOX(main_box), button_box);
