@@ -5,7 +5,7 @@ typedef struct
 {
 	gchar *cddev;
 	gchar *cddb, *remote_path, *proxy_server;
-	gint  cddbport, proxy_port;
+	gint  cddbport, proxy_port, time_display;
 	gboolean handle;
 	gboolean tooltip;
 	gboolean use_http, use_proxy;
@@ -17,5 +17,6 @@ typedef struct
 
 void load_properties( tcd_properties *prop );
 void save_properties( tcd_properties *prop );
+void properties_cb( GtkWidget *widget, void *data );
 
 #endif
