@@ -28,7 +28,11 @@
    
 
 #include <fcntl.h>
+#if defined(USE_NCURSES) && !defined(RENAMED_NCURSES)
+#include <ncurses.h>
+#else
 #include <curses.h>
+#endif
 #include <stdio.h>
 #include <unistd.h>
 #include <stdlib.h>
@@ -667,7 +671,7 @@ void tcd_get_cddb( void )
 	server.port = 888;
 	                
 	mvwprintw( win, maxy-1, 2, "Connecting to cddb.cddb.com:888...   " );refresh();	
-	if( tcd_open_cddb( &server ) != 0 )
+	if( tcd_open_cddb( &server, NULL ) != 0 )
 	{
 		mvwprintw( win, maxy-1, 2, "Error: %s                    ", server.error );refresh();	
 		sleep(2);
@@ -678,7 +682,7 @@ void tcd_get_cddb( void )
 	tcd_formatquery( cd, test ,sizeof(test));
         r = send( server.socket, test, strlen(test), 0 );
 	
-        tcd_getquery( &server, &query );
+        tcd_getquery( &server, &query, NULL );
 	
 	mvwprintw( win, maxy-1, 2, "Album found. Downloading information." );refresh();	
  
@@ -687,11 +691,17 @@ void tcd_get_cddb( void )
 
 	sprintf( test, "%s/.tcd/%s", getenv("HOME"),query.discid );
 	outfile = fopen( test, "w" );
-
+	if (outfile == NULL)
+	{
+        	mvwprintw( win, maxy-1, 2, "Can't open local file.  Aborting. ");
+        	refresh();
+		close(server.socket);
+                return;
+        }   
 	i=0;
 	do
 	{
-		fgetsock( s, 80, server.socket );
+		fgetsock( s, 80, server.socket,NULL );
 	        fprintf( outfile, "%s\n", s );
 		mvwprintw( win, maxy-1, 2, "Downloading line %3d...             ",i++ );refresh();
 	} while( strcmp( ".", s ) );
